@@ -1,8 +1,10 @@
 package POEx::ZMQ;
-$POEx::ZMQ::VERSION = '0.001002';
+$POEx::ZMQ::VERSION = '0.002001';
 use Carp;
 use strictures 1;
 
+use Scalar::Util 'blessed';
+
 use Import::Into;
 
 use POEx::ZMQ::FFI::Context;
@@ -10,7 +12,11 @@ use POEx::ZMQ::FFI::Context;
 use POEx::ZMQ::Constants ();
 use POEx::ZMQ::Socket ();
 
-=for Pod::Coverage import
+sub ZCTX () { 0 }
+
+use namespace::clean;
+
+=for Pod::Coverage import ZCTX
 
 =cut
 
@@ -19,9 +25,28 @@ sub import {
   POEx::ZMQ::Constants->import::into($pkg, '-all');
 }
 
-sub context { shift; POEx::ZMQ::FFI::Context->new(@_) }
+sub new {
+  my ($class, %param) = @_;
+  bless [ $param{context} ], $class
+}
 
-sub socket { shift; POEx::ZMQ::Socket->new(@_) }
+sub context {
+  my $self_or_class = shift;
+  if (blessed $self_or_class) {
+    return ( $self_or_class->[ZCTX] ||= POEx::ZMQ::FFI::Context->new(@_) )
+  }
+  POEx::ZMQ::FFI::Context->new(@_)
+}
+
+sub socket {
+  my ($self_or_class, %param) = @_;
+  POEx::ZMQ::Socket->new(
+    context => (
+      exists $param{context} ? delete $param{context} : $self_or_class->context
+    ),
+    %param
+  )
+}
 
 1;
 
@@ -41,13 +66,12 @@ POEx::ZMQ - Asynchronous ZeroMQ sockets for POE
   POE::Session->create(
     inline_states => +{
       _start => sub {
-        # Set up a ROUTER; save our Context for creating other sockets later:
-        $_[HEAP]->{ctx} = POEx::ZMQ->context;
+        # Set up a ROUTER
+        # Save our POEx::ZMQ for creating other sockets w/ shared context later:
+        my $zmq = POEx::ZMQ->new;
+        $_[HEAP]->{zeromq} = $zmq;
 
-        $_[HEAP]->{rtr} = POEx::ZMQ->socket(
-          context => $_[HEAP]->{ctx},
-          type    => ZMQ_ROUTER,
-        );
+        $_[HEAP]->{rtr} = $zmq->socket( type => ZMQ_ROUTER );
 
         $_[HEAP]->{rtr}->start;
 
@@ -60,8 +84,7 @@ POEx::ZMQ - Asynchronous ZeroMQ sockets for POE
         my $parts = $_[ARG0];
         my ($id, undef, $content) = $parts->all;
 
-        my $response;
-        # ...
+        my $response = 'foo';
 
         # $_[SENDER] was the ROUTER socket, send a response back:
         $_[KERNEL]->post( $_[SENDER], send_multipart =>
@@ -100,21 +123,52 @@ ZeroMQ implementation.
 Importing this package brings in the full set of L<POEx::ZMQ::Constants>, and
 ensures L<POEx::ZMQ::Socket> is loaded.
 
+=head3 new
+
+  my $zmq = POEx::ZMQ->new;
+  # POEx::ZMQ::FFI::Context obj is automatically shared:
+  my $frontend = $zmq->socket(type => ZMQ_ROUTER);
+  my $backend  = $zmq->socket(type => ZMQ_ROUTER);
+
+This class can be instanced, in which case it will hang on to the first
+L</context> created (possibly implicitly via a call to L</socket>) and use
+that L<POEx::ZMQ::FFI::Context> instance for all calls to L</socket>.
+
 =head3 context
 
   my $ctx = POEx::ZMQ->context(max_sockets => 512);
 
-Returns a new L<POEx::ZMQ::FFI::Context>. C<@_> is passed through.
+If called as a class method, returns a new L<POEx::ZMQ::FFI::Context>.
+
+  my $zmq = POEx::ZMQ->new;
+  my $ctx = $zmq->context;
+
+If called as an object method, returns the context object belonging to the
+instance. If none currently exists, a new L<POEx::ZMQ::FFI::Context> is
+created (and preserved for use during socket creation; see L</socket>).
+
+If creating a new context object, C<@_> is passed through to the
+L<POEx::ZMQ::FFI::Context> constructor.
 
 The context object should be shared between sockets belonging to the same
-process; a forked child process should create a new context with its own set
+process -- a forked child process must create a new context with its own set
 of sockets.
 
 =head3 socket
 
   my $sock = POEx::ZMQ->socket(context => $ctx, type => ZMQ_ROUTER);
 
-Returns a new L<POEx::ZMQ::Socket>. C<@_> is passed through.
+If called as a class method, returns a new L<POEx::ZMQ::Socket> using either
+a provided C<context> or, if missing from arguments, a freshly-created
+L<POEx::ZMQ::FFI::Context>.
+
+  my $sock = $zmq->socket(type => ZMQ_ROUTER);
+
+If called as an object method, returns a new L<POEx::ZMQ::Socket> that uses
+the L<POEx::ZMQ::FFI::Context> object belonging to the instance; see
+L</context>.
+
+C<@_> is passed through to the L<POEx::ZMQ::Socket> constructor.
 
 =head1 AUTHOR
 
