@@ -1,5 +1,5 @@
 package POEx::ZMQ::FFI::Socket;
-$POEx::ZMQ::FFI::Socket::VERSION = '0.001002';
+$POEx::ZMQ::FFI::Socket::VERSION = '0.002001';
 use v5.10;
 use Carp;
 use strictures 1;
@@ -41,7 +41,7 @@ use Moo; use MooX::late;
 has context => (
   required  => 1,
   is        => 'ro',
-  isa       => InstanceOf['POEx::ZMQ::FFI::Context'],
+  isa       => ZMQContext,
 );
 
 has type    => (
@@ -600,7 +600,7 @@ try to Do The Right Thing.
 The internal C<< option => type >> map is exposed via L</known_type_for_opt>;
 it should be reasonably complete. B<< If you have to specify your own value
 type for a new or missing option, file a bug >> via
-L<< http://www.github.com/avenj/poex-zmq|GitHub >> or RT.
+L<< github|http://www.github.com/avenj/poex-zmq >> or RT.
 
 =head3 set_sock_opt
 
@@ -616,7 +616,7 @@ See the L<zmq_setsockopt(3)> man page.
 Returns a file handle (suitable for polling by an event loop such as L<POE>) by
 performing an L<fdopen(3)> on the file descriptor returned by the C<ZMQ_FD>
 socket option; see L<zmq_getsockopt(3)> and the
-L<http://zguide.zeromq.org|zguide>.
+L<< zguide|http://zguide.zeromq.org >>.
 
 =head3 get_raw_socket
 
